@@ -63,8 +63,7 @@ public class ConvPara {
     private static Map<Integer, String> characterStyleNameMap = new HashMap<Integer, String>();
     private static final String PARAGRAPH_STYLE_PREFIX = "HWP ";
 
-    static final double PARABREAK_SPACING = 0.86;
-    static final double PARA_SPACING = 0.85;
+    static final double PARA_SPACING = 0.85; // 0.75;
     
     public static void reset(WriterContext wContext) {
         deleteCustomStyles(wContext);
@@ -114,7 +113,7 @@ public class ConvPara {
             XPropertySet xStyleProps = (XPropertySet) UnoRuntime.queryInterface(XPropertySet.class, xFamily.getByName(hwpStyleName));
             
             if (paraShape!=null) {
-                setParagraphProperties(xStyleProps, paraShape, wContext.getDocInfo().compatibleDoc, PARA_SPACING);
+                setParagraphProperties(xStyleProps, paraShape, wContext.getDocInfo().compatibleDoc, charShape.lineSpaceAlpha);
             }
             if (charShape!=null) {
                 HwpRecord_BorderFill borderFill = wContext.getBorderFill(charShape.borderFillIDRef);
@@ -212,14 +211,13 @@ public class ConvPara {
                 xStyleProps.setPropertyValue("ParaAdjust", ParagraphAdjust.CENTER);
                 break;
             case JUSTIFY:
-                xStyleProps.setPropertyValue("ParaAdjust", ParagraphAdjust.BLOCK);
-                // xStyleProps.setPropertyValue("ParaLastLineAdjust", (short)2);
+                xStyleProps.setPropertyValue("ParaAdjust", ParagraphAdjust.LEFT);	// 양쪽정렬은 왼쪽정렬과 조금 더 유사하다. 특히 LINE_BREAK 올때 
                 break;
             case DISTRIBUTE:
-            case DISTRIBUTE_SPACE:
                 xStyleProps.setPropertyValue("ParaAdjust", ParagraphAdjust.BLOCK);
-                xStyleProps.setPropertyValue("ParaLastLineAdjust", (short)2);
-                xStyleProps.setPropertyValue("ParaExpandSingleWord", true);
+                break;
+            case DISTRIBUTE_SPACE:
+                xStyleProps.setPropertyValue("ParaAdjust", ParagraphAdjust.STRETCH);
                 break;
             }
             // breakLatinWord                       // 줄 나눔 기준 영어 단위 (0:단어, 1:하이픈, 2:글자)
@@ -437,9 +435,13 @@ public class ConvPara {
                 align = ParagraphAdjust.CENTER;
                 break;
             case JUSTIFY:
+            	align = ParagraphAdjust.LEFT;  // 양쪽정렬은 LEFT와 유사. 특히 LINE_BREAK가 있을때
+            	break;
             case DISTRIBUTE:
+            	align = ParagraphAdjust.BLOCK;
+            	break;
             case DISTRIBUTE_SPACE:
-                align = ParagraphAdjust.BLOCK;
+                align = ParagraphAdjust.STRETCH;
                 break;
             }
             xStyleProps.setPropertyValue("ParaAdjust", align);
@@ -996,4 +998,5 @@ public class ConvPara {
         return characterStyleNameMap.get(styleID);
     }
 
+    
 }
