@@ -1053,7 +1053,7 @@ public class ConvTable {
 
             try {
                 paraProps.setPropertyValue("ParaStyleName", styleName);
-                ConvPara.setParagraphProperties(paraProps, captionParaShape, wContext.getDocInfo().compatibleDoc, ConvPara.PARA_SPACING);
+                ConvPara.setParagraphProperties(paraProps, captionParaShape, wContext.getDocInfo().compatibleDoc, captionCharShape.lineSpaceAlpha);
                 HwpRecord_BorderFill borderFill = wContext.getBorderFill(captionCharShape.borderFillIDRef);
                 ConvPara.setCharacterProperties(paraProps, captionCharShape, borderFill, step);
                 paraProps.setPropertyValue("ParaTopMargin", Transform.translateHwp2Office(table.captionSpacing));
@@ -1202,10 +1202,10 @@ public class ConvTable {
                 @Override
                 public boolean onParaBreak() {
                     if (isLastPara == false) {
-                        HwpRecurs.insertParaString(childContext, "\r", para.lineSegs, styleName, paraStyle, paraShape,
-                                charShape, true, true, step);
+                    	return false;
+                    } else {
+                    	return true;
                     }
-                    return true;
                 }
             };
             HwpRecurs.printParaRecurs(childContext, wContext, para, callback, 2);
